@@ -16,12 +16,12 @@ import flask
 from injector import Injector
 from flask import Config, Request
 from werkzeug.local import Local, LocalManager
-from injector import Module, Scope, ScopeDecorator, singleton, InstanceProvider
+from injector import Module, Provider, Scope, ScopeDecorator, singleton, InstanceProvider
 
 
 __author__ = 'Alec Thomas <alec@swapoff.org>'
-__version__ = '0.3.2'
-__all__ = ['request', 'RequestScope', 'Config', 'Request', ]
+__version__ = '0.3.3'
+__all__ = ['init_app', 'post_init_app', 'request', 'RequestScope', 'Config', 'Request', ]
 
 
 def wrap_fun(fun, injector):
@@ -37,6 +37,20 @@ def wrap_fun(fun, injector):
     return wrapper
 
 
+class CachedProviderWrapper(Provider):
+    def __init__(self, old_provider):
+        self._old_provider = old_provider
+        self._cache = {}
+
+    def get(self, injector):
+        key = id(injector)
+        try:
+            return self._cache[key]
+        except KeyError:
+            instance = self._cache[key] = self._old_provider.get(injector)
+            return instance
+
+
 class RequestScope(Scope):
     """A scope whose object lifetime is tied to a request.
 
@@ -55,7 +69,7 @@ class RequestScope(Scope):
         self.reset()
 
     try:
-        from injector import BounderProvider  # noqa
+        from injector import BoundProvider  # noqa
     except ImportError:
         def get(self, key, provider):
             try:
@@ -65,21 +79,6 @@ class RequestScope(Scope):
                 self._locals.scope[key] = provider
                 return provider
     else:
-        from injector import Provider
-
-        class CachedProviderWrapper(Provider):
-            def __init__(self, old_provider):
-                self._old_provider = old_provider
-                self._cache = {}
-
-            def get(self, injector):
-                key = id(injector)
-                try:
-                    return self._cache[key]
-                except KeyError:
-                    instance = self._cache[key] = self._old_provider.get(injector)
-                    return instance
-
         def get(self, key, provider):
             try:
                 return self._locals.scope[key]
